# load example data set
data("growth_data")
# Run function with three default model candidates and return results
# without plots. Use 100 bootstraps for testing and then increase to at
# least 1000 for actual model runs.
models <- Estimate_Growth(growth_data, plots = FALSE, n.bootstraps = 100)
# Calculate the model average of the resulting growth estimates
Calculate_MMI(models)
Run the code above in your browser using DataLab